@@ -1,22 +1,15 @@
 package Dist::Zilla::Plugin::Substitute;
-$Dist::Zilla::Plugin::Substitute::VERSION = '0.005';
+$Dist::Zilla::Plugin::Substitute::VERSION = '0.006';
 use Moose;
 use Moose::Util::TypeConstraints;
-use MooseX::Types::Moose qw/ArrayRef CodeRef/;
-
+use MooseX::Types::Moose qw/ArrayRef CodeRef Str/;
+use List::Util 'first';
 use Carp 'croak';
 
-with qw/Dist::Zilla::Role::FileMunger/;
-
-has finders => (
-	is      => 'bare',
-	isa     => 'ArrayRef',
-	default => sub { [qw/:InstallModules :ExecFiles/] },
-	traits  => ['Array'],
-	handles => {
-		finders => 'elements',
-	},
-);
+with 'Dist::Zilla::Role::FileMunger',
+	'Dist::Zilla::Role::FileFinderUser' => {
+		default_finders => [ ':InstallModules', ':ExecFiles' ],
+	};
 
 my $codeliteral = subtype as CodeRef;
 coerce $codeliteral, from ArrayRef, via {
@@ -38,47 +31,47 @@ has filename_code => (
 );
 
 sub mvp_multivalue_args {
-	return qw/finders code filename_code files/;
+	return qw/code filename_code files/;
 }
 
 sub mvp_aliases {
 	return {
 		content_code => 'code',
-		finder       => 'finders',
 		file         => 'files',
 	};
 }
 
 has files => (
-	is      => 'bare',
-	isa     => ArrayRef,
-	builder => '_build_files',
+	isa     => ArrayRef[Str],
 	traits  => ['Array'],
 	lazy    => 1,
+	default => sub { [] },
 	handles => {
 		files => 'elements',
 	},
 );
 
-sub _build_files {
-	my $self     = shift;
-	my @filesets = map { @{ $self->zilla->find_files($_) } } $self->finders;
-	my %files    = map { $_->name => $_ } @filesets;
-	return [ values %files ];
-}
-
 sub munge_files {
 	my $self = shift;
-	$self->munge_file($_) for $self->files;
+
+	if (my @filenames = $self->files) {
+		foreach my $file (@{ $self->zilla->files }) {
+			$self->munge_file($file) if first { $file->name eq $_ } @filenames;
+		}
+	}
+	else {
+		$self->munge_file($_) for @{ $self->found_files };
+	}
+
 	return;
 }
 
 sub munge_file {
 	my ($self, $file) = @_;
-	my @content = split /\n/, $file->content;
+	my @content = split /^/m, $file->content;
 	my $code = $self->code;
 	$code->() for @content;
-	$file->content(join "\n", @content);
+	$file->content(join '', @content);
 
 	if ($self->_has_filename_code) {
 		my $filename      = $file->name;
@@ -106,7 +99,7 @@ Dist::Zilla::Plugin::Substitute - Substitutions for files in dzil
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -143,7 +136,7 @@ The finders to use for the substitutions. Defaults to C<:InstallModules, :ExecFi
 
 The files to substitute. It defaults to the files in C<finders>. May also be spelled as C<file> in the dist.ini.
 
-# vi:noet:sts=2:sw=2:ts=2
+# vim: ts=2 sts=2 sw=2 noet :
 
 =head1 AUTHOR
 
